@@ -40,14 +40,13 @@ class NEMIVER_API IDBGPerspective : public IPerspective {
 
 public:
 
-    IDBGPerspective () {};
+    IDBGPerspective (DynamicModule *a_dynmod) :
+        IPerspective (a_dynmod)
+    {
+    }
 
     virtual ~IDBGPerspective () {};
 
-    virtual void get_info (Info &a_info) const = 0;
-
-    virtual void do_init ()  = 0;
-
     virtual void do_init (IWorkbench *a_workbench)  = 0;
 
     virtual const UString& get_perspective_identifier () = 0;
@@ -115,7 +114,8 @@ public:
 
     virtual bool get_breakpoint_number (const UString &a_file_name,
                                         int a_linenum,
-                                        int &a_break_num) = 0 ;
+                                        int &a_break_num,
+                                        bool &a_enabled) = 0 ;
 
     virtual bool delete_breakpoint () = 0;
 
@@ -125,7 +125,8 @@ public:
                                     int a_linenum) = 0;
 
     virtual bool append_visual_breakpoint (const UString &a_file_name,
-                                           int a_linenum) = 0;
+                                           int a_linenum,
+                                           bool enabled=true) = 0;
 
     virtual void delete_visual_breakpoint (const UString &a_file_name,
                                            int a_linenum) = 0;
@@ -141,7 +142,9 @@ public:
 
     virtual void add_text_to_log_view (const UString &a_text) = 0;
 
-    virtual void set_where (const UString &a_uri, int line) = 0;
+    virtual void set_where (const UString &a_uri,
+                            int line,
+                            bool a_do_scroll=true) = 0;
 
     virtual Gtk::Widget* get_contextual_menu () = 0;
 
